Vagas pra mim

Conteúdo do currículo

extensa
restrita

#### Veja mais

#### Contribute to the project

Ajude este projeto a crescer. Pull requests são bem-vindas. Para mudanças grandes crie uma issue para discutirmos o que está sendo modificado. Adicione os testes apropriados. Dê uma estrelinha se você gostou deste projeto :)

#### Playing with PyScript, Postgres and K8S

I’ve talked in other posts about my hobby of experimenting with technologies that interest me. This time I spent some time experimenting with PyScript. I have to say that I decided to study PyScript, because I’m a no-no with JavaScript and I wanted to know if using PyScript it would be possible to get the same results I get when using JavaScript. So, in my tests I used pure Python to develop an application that integrates front-end, back-end and some database.

#### QA e Dev parem de brigar

The intention of this project is to create a chatbot based on movie reviews so that you can ask questions and have a free conversation about this topic.

#### Building a Chat Bot using AI with movie scripts dataset

The intention of this project is to create a chatbot based on movie reviews so that you can ask questions and have a free conversation about this topic. Recently I had to buy a new internet service, so I tried to do it using the available chatbot of the company. I noticed the conversation with the chatbot was based on rules and conditions. Hence, for each question I was doing to the bot, it was sending to me a list of options I needed to choose to go to the next step of the conversation. The experience was not good for me and it did not solve my problem. So, I started search for possible solutions, just for curiosity, and I found some contents in the internet talking about the training of a chatbot using Natural Language Processing (NLP). After this reading, I decided to take the challenge and train my on chatbot for natural conversations.

#### Como foi palestrar no TDC

Em 2019, quando ainda podíamos participar de eventos presenciais sem nos preocupar com aglomerações, fui convidado para palestrar na maior conferência de desenvolvedores da América Latina: The Developer’s Conference (TDC).

#### Testing Windows Apps with HTTP REST

Did you already have the necessity to test a Frankenstein app that had the operation mixed in Desktop, Web and Mobile pages? So, keep reading this post. This is for you.

#### Find jobs using ML and help people

Here in Brazil the situation is not good nowadays. We have more than 500 thousands of dead people by Covid-19, many companies closed the doors, hence a lot of people lose their jobs. In my LinkedIn feed every day there is a new post about someone that was fired and is searching for a new job position. Some months ago, before the pandemic, something similar happened to me. More than 80 people including me, were fired suddenly because our company loose a very big project that was responsible for more than 60% for its revenue.

#### MTC 2021 Conversa sobre shift left

Douglas Cardoso apresenta no Minas Testing Conference (MTC) os conceitos de termo 'Shift left' que vem sendo difundido nos últimos anos na comunidade de testes de software.

#### Building a Chat Bot

Recently I had to buy a new internet service, so I tried to do it using the available chatbot of the company. I noticed the conversation with the chatbot was based on rules and conditions. Hence, for each question I was doing to the bot, it was sending to me a list of options I needed to choose to go to the next step of the conversation. The experience was not good for me and it did not solve my problem. So, I started search for possible solutions, just for curiosity, and I found some contents in the internet talking about the training of a chat bot using Natural Language Processing (NLP). After this reading, I decided to take the challenge and train my on chatbot for natural conversations.

#### Mais de 2000 empresas para você

Lista de mais de 2000 empresas de brasileiras para se cadastrar e conseguir um novo emprego.

#### TDC Load test

Douglas Cardoso apresenta no The Developer's Conference conceitos de teste de performance e alguns resultados reais.

#### Strategy pattern em testes de software

Vídeo com um exemplo de implementação do padrão de projeto 'Strategy' para automação de testes de software.

#### Object Repository usando o Selenium

Vídeo com implementação de uma forma fácil de mapear as páginas de uma interface gráfica para automação de testes de software.

#### IA em testes de software (PSO e GA)

Apresentação com exemplos de utilização de inteligência artificial em testes de software.

#### Livro infantil 'Poli escolhe'

Para abordar a temática da escolha das crianças, a autora Cláudia Rezende, que é jornalista, pensou em uma situação muito comum entre as gerações, que é a definição de qual vai ser o time de futebol do coração do filho. Assim, a partir de um encontro num parquinho, a dúvida se estabelece na protagonista, e o enredo se desenvolve, com Poli muitas vezes colocando os adultos contra a parede. A ideia, conforme a jornalista, é propor a reflexão sobre as interferências que os pais fazem nas escolhas dos filhos e a possibilidade de proporcionar a estes o desenvolvimento da autonomia do pensar já desde a infância. O livro não deixa, também, de levar uma mensagem de paz entre as torcidas, já que a rivalidade deve ser mesmo só nos gramados, certo?

#### Xpath para testadores

Vídeo com conceitos e exemplos práticos de utilização de Xpath em automação de testes de software.

#### Música 'Suportar'

'Suportar', música da banda 'Lasciva Lula' lançada no disco Sublime Mundo Crânio (2007). Clipe inspirado na série de quarentena do fotógrafo Lauro Machado.

#### Dataset de defeitos

Este dataset foi criado para ser usado em um exercício de ML a fim de ser descobrir se os eventos e errors de um computador pessoal Windows tinham alguma relação, ou associação entre eles. Isso é uma simples extração de dados do Windows Events Viewer de um computador pessoal.

#### Unit Testing Dependencies

Author 'Vladimir Khorikov'. In this article, we’ll review the types of unit testing dependencies. This is more of a reference article, to which I’ll be referring in future posts. Still, this topic is important for establishing the common vocabulary